@@ -29,14 +29,15 @@
 
 #include "freebusyganttproxymodel.h"
 
+#include <Akonadi/Calendar/FreeBusyManager>
+
 #include <EventViews/AgendaView>
 #include <EventViews/ViewCalendar>
 
 #include <KCalCore/Event>
 #include <KCalCore/MemoryCalendar>
+
 #include <KGantt/KGanttGraphicsView>
-#include <akonadi/calendar/freebusymanager.h>
-#include <kldap/ldapobject.h>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -114,6 +115,7 @@ public:
 ResourceManagement::ResourceManagement(QWidget *parent)
     : QDialog(parent)
 {
+    setWindowTitle(i18n("Resource Management"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
         QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -210,7 +212,7 @@ void ResourceManagement::slotShowDetails(const QModelIndex &current)
 void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::LdapClient &client)
 {
     // Clean up formDetails
-    QLayoutItem *child;
+    QLayoutItem *child = nullptr;
     while ((child = mUi->formDetails->takeAt(0)) != nullptr) {
         delete child->widget();
         delete child;
@@ -265,7 +267,7 @@ void ResourceManagement::slotLayoutChanged()
 void ResourceManagement::slotOwnerSearchFinished()
 {
     // Clean up formDetails
-    QLayoutItem *child;
+    QLayoutItem *child = nullptr;
     while ((child = mUi->formOwner->takeAt(0)) != nullptr) {
         delete child->widget();
         delete child;
